@@ -8,6 +8,17 @@ class Document(metaclass=abc.ABCMeta):
     A document is identified by grouping a list of paragraph.
    """
 
+    @abc.abstractmethod
+    def sentiment(self) -> Dict[str, float]:
+        """
+        Returns the document polarities. <br/>
+        Each polarity value is between 0 and 1. They are calculated as the average of the paragraphs polarities greater than 0. <br/>
+        _p_ in _[0,1]_
+
+        Returns:
+            Dict[str, float]: Polarities type as keys, sentiment values as values.
+        """
+
     @abc.abstractmethod
     def named_entities(self) -> List[str]:
         """Returns named entities in the document."""
