@@ -1,7 +1,7 @@
 from typing import *
 from compling.config import ConfigManager
 import compling.analysis.lexical.tokenization.document_abc as abcdoc
-from compling.analysis.lexical.tokenization.impl.paragraph import Paragraph
+from compling.analysis.lexical.tokenization.impl.paragraph import Paragraph, f2att
 
 
 class Document(abcdoc.Document):
@@ -37,6 +37,37 @@ class Document(abcdoc.Document):
         # add metaddata for this document record
         self.add_metadata(metadata)
 
+    @f2att
+    def sentiment(self) -> Dict[str, float]:
+        """
+        Returns the document polarities. <br/>
+        Each polarity value is between 0 and 1. They are calculated as the average of the paragraphs polarities greater than 0. <br/>
+        _p_ in _[0,1]_
+
+        Returns:
+            Dict[str, float]: Polarities type as keys, sentiment values as values.
+        """
+
+
+        sentiment_values = {'pos': 0.0, 'neg': 0.0}
+        count_gt0 = {'pos': 0, 'neg': 0}
+
+        for para in self.para_list:
+            for k in sentiment_values.keys():
+                if para.sentiment()[k] > 0:
+                    count_gt0[k] += 1
+                sentiment_values[k] += para.sentiment()[k]
+
+        for k in sentiment_values.keys():
+            if count_gt0[k] > 0:
+                if k in ("pos", "neg"):
+                    sentiment_values[k] /= max(count_gt0["pos"], count_gt0["neg"])
+                else:
+                    sentiment_values[k] /= count_gt0[k]
+
+        return sentiment_values
+
+    @f2att
     def named_entities(self) -> List[Dict[str, Union[str, int]]]:
         """Returns named entities in the document."""
 
@@ -63,15 +94,18 @@ class Document(abcdoc.Document):
         """Returns the lower of the document."""
         return self.text_.lower()
 
+    @f2att
     def lemma(self) -> str:
         """Returns a version of the document text with tokens replace by their lemma."""
         return " . ".join([sentence.lemma() for sentence in self.para_list])
 
+    @f2att
     def negations(self) -> str:
         """Returns the text of the document where the text of negated tokens are preceded by the prefix 'NOT_'."""
 
         return " . ".join([para.negations() for para in self.para_list])
 
+    @f2att
     def stem(self) -> str:
         """Returns a version of the document text with tokens replace by their stem."""
         return " . ".join([sentence.stem() for sentence in self.para_list])
