@@ -1,7 +1,7 @@
 from typing import *
 from compling.config import ConfigManager
 import compling.analysis.lexical.tokenization.paragraph_abc as abcpara
-from compling.analysis.lexical.tokenization.impl.sentence import Sentence
+from compling.analysis.lexical.tokenization.impl.sentence import Sentence, f2att
 
 
 class Paragraph(abcpara.Paragraph):
@@ -37,6 +37,7 @@ class Paragraph(abcpara.Paragraph):
         # add metadata for this paragraph record
         self.add_metadata(metadata)
 
+    @f2att
     def named_entities(self) -> List[Dict[str, Union[str, int]]]:
         """Returns named entities in the paragraph."""
 
@@ -63,16 +64,48 @@ class Paragraph(abcpara.Paragraph):
         """Return the lowercase text of the paragraph."""
         return self.text_.lower()
 
+    @f2att
     def lemma(self) -> str:
         """Returns a version of the paragraph text with tokens replace by their lemma."""
 
         return " . ".join([sentence.lemma() for sentence in self.sent_list])
 
+    @f2att
     def negations(self) -> str:
         """Return the text of the paragraph where the text of negated tokens are preceded by the prefix 'NOT_'."""
 
         return " . ".join([sent.negations() for sent in self.sent_list])
 
+    @f2att
+    def sentiment(self) -> Dict[str, float]:
+        """
+        Returns the paragraph polarities. <br/>
+        Each polarity value is between 0 and 1. They are calculated as the average of the sentences polarities greater than 0. <br/>
+        _p_ in _[0,1]_
+
+        Returns:
+            Dict[str, float]: Polarities type as keys, sentiment values as values.
+        """
+
+        sentiment_values = {'pos': 0.0, 'neg': 0.0}
+        count_gt0 = {'pos': 0, 'neg': 0}
+
+        for sent in self.sent_list:
+            for k in sentiment_values.keys():
+                if sent.sentiment()[k] > 0:
+                    count_gt0[k] += 1
+                sentiment_values[k] += sent.sentiment()[k]
+
+        for k in sentiment_values.keys():
+            if count_gt0[k] > 0:
+                if k in ("pos", "neg"):
+                    sentiment_values[k] /= max(count_gt0["pos"], count_gt0["neg"])
+                else:
+                    sentiment_values[k] /= count_gt0[k]
+
+        return sentiment_values
+
+    @f2att
     def stem(self) -> str:
         """Returns a version of the paragraph text with tokens replace by their stem."""
         return " . ".join([sentence.stem() for sentence in self.sent_list])
