@@ -222,8 +222,8 @@ class SentimentAnalyzer(SentimentLexiconBased):
         plt.figure(figsize=figsize)
         plt.plot()
 
-        polarities = {"pos": {"color": "r", "label": "Positive (+)"},
-                      "neg": {"color": "b", "label": "Negative (-)"}}
+        polarities = {"pos": {"color": "red", "label": "Positive (+)"},
+                      "neg": {"color": "black", "label": "Negative (-)"}}
 
         for polarity in polarities:
             plt.tight_layout()
